.. _api_config:

Configuration Options (:mod:`pydicom.config`)
=============================================

.. currentmodule:: pydicom.config

*pydicom* configuration options

.. autosummary::
   :toctree: generated/

   allow_DS_float
   data_element_callback
   data_element_callback_kwargs
   datetime_conversion
   debug
   enforce_valid_values
   future_behavior
   overlay_data_handlers
   pixel_data_handlers
   reset_data_element_callback
   show_file_meta
   DS_decimal
   DS_numpy
   use_DS_decimal
   use_IS_numpy
   use_DS_numpy
   APPLY_J2K_CORRECTIONS
   INVALID_KEY_BEHAVIOR
   INVALID_KEYWORD_BEHAVIOR
